@@ -1,12 +1,12 @@
 """ Small demo of the Label component.  """
 
-from enthought.enable.example_support import DemoFrame, demo_main
-from enthought.enable.label import Label
+from enable.example_support import DemoFrame, demo_main
+from enable.label import Label
 
-from enthought.enable.api import Component, Container, Pointer, Window
+from enable.api import Component, Container, Pointer, Window
 
 class MyFrame(DemoFrame):
-    
+
     def _create_window(self):
         label = Label(bounds=[100, 50], position=[50,50], text="HELLO")
         label.bgcolor = "red"
