@@ -1,7 +1,8 @@
 """ A moveable box shape. """
 
+from __future__ import with_statement
 
-from enthought.enable.primitives.shape import Shape
+from enable.primitives.shape import Shape
 
 
 class Box(Shape):
@@ -13,21 +14,17 @@ class Box(Shape):
 
     def _draw_mainlayer(self, gc, view_bounds=None, mode='default'):
         """ Draw the component. """
-        
-        gc.save_state()
-                
-        gc.set_fill_color(self._get_fill_color(self.event_state))
+        with gc:
+            gc.set_fill_color(self._get_fill_color(self.event_state))
 
-        dx, dy = self.bounds
-        x, y = self.position
-        gc.rect(x, y, dx, dy)
-        gc.fill_path()
+            dx, dy = self.bounds
+            x, y = self.position
+            gc.rect(x, y, dx, dy)
+            gc.fill_path()
 
-        # Draw the shape's text.
-        self._draw_text(gc)
-
-        gc.restore_state()
+            # Draw the shape's text.
+            self._draw_text(gc)
 
         return
-    
+
 #### EOF ######################################################################
