@@ -1,9 +1,10 @@
 """ A moveable circle shape. """
 
+from __future__ import with_statement
 
 # Enthought library imports.
-from enthought.traits.api import Float
-from enthought.enable.primitives.shape import Shape
+from traits.api import Float
+from enable.primitives.shape import Shape
 
 
 class Circle(Shape):
@@ -20,7 +21,7 @@ class Circle(Shape):
 
     def _bounds_changed(self):
         """ Static trait change handler. """
-        
+
         w, h = self.bounds
 
         radius = min(w, h) / 2.0
@@ -42,19 +43,15 @@ class Circle(Shape):
 
     def _draw_mainlayer(self, gc, view_bounds=None, mode='default'):
         """ Draw the component. """
-        
-        gc.save_state()
+        with gc:
+            gc.set_fill_color(self._get_fill_color(self.event_state))
 
-        gc.set_fill_color(self._get_fill_color(self.event_state))
-        
-        x, y = self.position
-        gc.arc(x + self.radius, y + self.radius, self.radius, 0, 2*3.14159, False)
-        gc.fill_path()
+            x, y = self.position
+            gc.arc(x + self.radius, y + self.radius, self.radius, 0, 2*3.14159, False)
+            gc.fill_path()
 
-        # Draw the shape's text.
-        self._draw_text(gc)
-        
-        gc.restore_state()
+            # Draw the shape's text.
+            self._draw_text(gc)
 
         return
 
@@ -64,11 +61,11 @@ class Circle(Shape):
 
     def _radius_changed(self):
         """ Static trait change handler. """
-        
+
         diameter = self.radius * 2
 
         self.bounds = [diameter, diameter]
 
         return
-    
+
 #### EOF ######################################################################
