@@ -2,8 +2,8 @@
 
 
 # Enthought library imports.
-from enthought.enable.api import Container, Window
-from enthought.enable.example_support import DemoFrame, demo_main
+from enable.api import Container, Window
+from enable.example_support import DemoFrame, demo_main
 
 # Local imports
 from box import Box
@@ -12,7 +12,7 @@ from circle import Circle
 
 class MyFrame(DemoFrame):
     """ The top-level frame. """
-    
+
     ###########################################################################
     # 'DemoFrame' interface.
     ###########################################################################
@@ -39,14 +39,14 @@ class MyFrame(DemoFrame):
             fill_color = 'red',
             text       = 'Box 1'
         )
-        
+
         box2 = Box(
             bounds     = [100, 100],
             position   = [150, 150],
             fill_color = 'green',
             text       = 'Box 2'
         )
-        
+
         circle1 = Circle(
             radius     = 50,
             position   = [250,250],
