@@ -1,6 +1,6 @@
 
-from enthought.enable.api import OverlayContainer, Slider, Window
-from enthought.enable.example_support import demo_main, DemoFrame
+from enable.api import OverlayContainer, Slider, Window
+from enable.example_support import demo_main, DemoFrame
 
 class MyFrame(DemoFrame):
 
