@@ -1,14 +1,14 @@
 
 from numpy import array
 
-from enthought.enable.example_support import DemoFrame, demo_main
+from enable.example_support import DemoFrame, demo_main
 
-from enthought.enable.api import Container, Window
-from enthought.enable.text_grid import TextGrid
+from enable.api import Container, Window
+from enable.text_grid import TextGrid
 
 class MyFrame(DemoFrame):
     def _create_window(self):
-        
+
         strings = array([["apple", "banana", "cherry", "durian"],
                          ["eggfruit", "fig", "grape", "honeydew"]])
         grid = TextGrid(string_array=strings)
@@ -18,4 +18,4 @@ class MyFrame(DemoFrame):
 
 if __name__ == "__main__":
     demo_main(MyFrame, size=[500,100])
-    
+
