@@ -1,12 +1,12 @@
 
 import sys
-from enthought.tvtk.api import tvtk
-from enthought.mayavi import mlab
-from enthought.enable.vtk_backend.vtk_window import EnableVTKWindow
+from tvtk.api import tvtk
+from mayavi import mlab
+from enable.vtk_backend.vtk_window import EnableVTKWindow
 
 def main():
     from basic_move import Box
-    from enthought.enable.api import Container
+    from enable.api import Container
     container = Container()
     box = Box(bounds=[30,30], position=[20,20], padding=5)
     container.add(box)
@@ -20,7 +20,7 @@ def main():
     rwi = scene.interactor
 
     # Create the Enable Window
-    window = EnableVTKWindow(rwi, renderer, 
+    window = EnableVTKWindow(rwi, renderer,
             component=container,
             #istyle_class = tvtk.InteractorStyleSwitch,
             istyle_class = tvtk.InteractorStyle,
