@@ -1,12 +1,13 @@
+from __future__ import with_statement
 
 from numpy import array
 from pyglet.window import key, Window
 
 try:
-    from enthought.kiva.backend_gl import GraphicsContext
+    from kiva.gl import GraphicsContext
 except ImportError, e:
     raise Exception(e)
-from enthought.kiva.constants import FILL, STROKE, FILL_STROKE
+from kiva.constants import FILL, STROKE, FILL_STROKE
 
 class TestWindow(Window):
     """ Press Q or Escape to exit
@@ -22,20 +23,19 @@ class TestWindow(Window):
     def on_key_press(self, symbol, modifiers):
         if symbol in (key.ESCAPE, key.Q):
             self.has_exit = True
-    
+
     def draw(self):
         gc = self.gc
-        gc.save_state()
-        gc.clear((0, 1, 0, 1))
-        gc.set_stroke_color((1,1,1,1))
-        gc.set_line_width(2)
-        pts = array([[50, 50], [50,100], [100,100], [100,50]])
-        gc.begin_path()
-        gc.lines(pts)
-        gc.close_path()
-        gc.draw_path(STROKE)
-        gc.flush()
-        gc.restore_state()
+        with gc:
+            gc.clear((0, 1, 0, 1))
+            gc.set_stroke_color((1,1,1,1))
+            gc.set_line_width(2)
+            pts = array([[50, 50], [50,100], [100,100], [100,50]])
+            gc.begin_path()
+            gc.lines(pts)
+            gc.close_path()
+            gc.draw_path(STROKE)
+            gc.flush()
 
 
 def main():
