@@ -1,5 +1,5 @@
-from enthought.kiva import GraphicsContext
-   
+from enable.kiva_graphics_context import GraphicsContext
+
 gc = GraphicsContext((500,500))
 gc.clear()
 gc.rect(100,100,300,300)
