@@ -1,5 +1,5 @@
-from enthought.kiva import constants
-from enthought.kiva.backend_image import GraphicsContext
+from kiva import constants
+from kiva.image import GraphicsContext
 
 gc = GraphicsContext((100,100))
 
@@ -12,4 +12,4 @@ gc.rect(0, 0, 30, 30)
 gc.draw_path()
 
 gc.save("simple.bmp")
-   
+
