@@ -1,5 +1,5 @@
 import time
-from enthought.kiva.backend_image import GraphicsContext
+from kiva.image import GraphicsContext
 
 samples = 1
 pt = (250, 250)
@@ -45,4 +45,4 @@ t2 = time.clock()
 print 'without clip', t2 - t1
 
 gc_main.save("without_clip.bmp")
-    
+
