@@ -295,7 +295,8 @@ class GraphicsContextBase(object):
         path and active_subpath will probably need to be optimized somehow.
     """
 
-    def __init__(self):
+    def __init__(self, *args, **kwargs):
+        super(GraphicsContextBase, self).__init__()
         self.state = GraphicsState()
 
         # The line state has multiple properties that are tracked by a class
